Load one or more example resources from the
DMRsegaldata ExperimentHub package and assign them into the caller's
environment using their resource names.
Compatibility wrapper returning the chr5/chr11 example subset.
Compatibility wrapper returning the chr21/chr22 example subset.
Usage
loadExampleInputData(...)
loadExampleInputDataChr5And11(...)
loadExampleInputDataChr21And22(...)
Arguments
- ...
Names of the resources to load, or none to load all available
resources. Available resources:
"beta": Example beta values matrix
"pheno": Example phenotype data
"dmps": Example differentially methylated positions
"array_type": Example array type annotation
Value
Invisibly returns the loaded object when a single resource is
requested, or a named list of loaded objects when multiple resources are
requested.
Examples
# Load phenotype data into the current environment
loadExampleInputData("pheno")
head(pheno)
# Load multiple resources at once
loadExampleInputDataChr5And11("beta", "dmps", "pheno", "array_type")
dim(beta)